==> zio-aws-cloudfront_2.12-7.30.22.1-sources.jar: zio/aws/cloudfront/model/UpdateDistributionResponse.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateDistributionResponse(
    distribution: Optional[zio.aws.cloudfront.model.Distribution] =
      Optional.Absent,
    eTag: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.UpdateDistributionResponse = {
    import UpdateDistributionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.UpdateDistributionResponse
      .builder()
      .optionallyWith(distribution.map(value => value.buildAwsValue()))(
        _.distribution
      )
      .optionallyWith(eTag.map(value => value: java.lang.String))(_.eTag)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.UpdateDistributionResponse.ReadOnly =
    zio.aws.cloudfront.model.UpdateDistributionResponse.wrap(buildAwsValue())
}
object UpdateDistributionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.UpdateDistributionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.UpdateDistributionResponse =
      zio.aws.cloudfront.model.UpdateDistributionResponse(
        distribution.map(value => value.asEditable),
        eTag.map(value => value)
      )
    def distribution: Optional[zio.aws.cloudfront.model.Distribution.ReadOnly]
    def eTag: Optional[String]
    def getDistribution
        : ZIO[Any, AwsError, zio.aws.cloudfront.model.Distribution.ReadOnly] =
      AwsError.unwrapOptionField("distribution", distribution)
    def getETag: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("eTag", eTag)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.UpdateDistributionResponse
  ) extends zio.aws.cloudfront.model.UpdateDistributionResponse.ReadOnly {
    override val distribution
        : Optional[zio.aws.cloudfront.model.Distribution.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.distribution())
        .map(value => zio.aws.cloudfront.model.Distribution.wrap(value))
    override val eTag: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.eTag())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.UpdateDistributionResponse
  ): zio.aws.cloudfront.model.UpdateDistributionResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-cloudfront_2.13-5.17.104.9-sources.jar: zio/aws/cloudfront/model/UpdateDistributionResponse.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateDistributionResponse(
    distribution: Option[zio.aws.cloudfront.model.Distribution] = None,
    eTag: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.UpdateDistributionResponse = {
    import UpdateDistributionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.UpdateDistributionResponse
      .builder()
      .optionallyWith(distribution.map(value => value.buildAwsValue()))(
        _.distribution
      )
      .optionallyWith(eTag.map(value => value: java.lang.String))(_.eTag)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.UpdateDistributionResponse.ReadOnly =
    zio.aws.cloudfront.model.UpdateDistributionResponse.wrap(buildAwsValue())
}
object UpdateDistributionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.UpdateDistributionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.UpdateDistributionResponse =
      zio.aws.cloudfront.model.UpdateDistributionResponse(
        distribution.map(value => value.asEditable),
        eTag.map(value => value)
      )
    def distribution: Option[zio.aws.cloudfront.model.Distribution.ReadOnly]
    def eTag: Option[String]
    def getDistribution
        : ZIO[Any, AwsError, zio.aws.cloudfront.model.Distribution.ReadOnly] =
      AwsError.unwrapOptionField("distribution", distribution)
    def getETag: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("eTag", eTag)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.UpdateDistributionResponse
  ) extends zio.aws.cloudfront.model.UpdateDistributionResponse.ReadOnly {
    override val distribution
        : Option[zio.aws.cloudfront.model.Distribution.ReadOnly] = scala
      .Option(impl.distribution())
      .map(value => zio.aws.cloudfront.model.Distribution.wrap(value))
    override val eTag: Option[String] =
      scala.Option(impl.eTag()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.UpdateDistributionResponse
  ): zio.aws.cloudfront.model.UpdateDistributionResponse.ReadOnly = new Wrapper(
    impl
  )
}
